Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/scicom/__init__.py | 0 | 0 | 0 | 100%
src/scicom/historicalletters/__init__.py | 0 | 0 | 0 | 100%
src/scicom/historicalletters/agents.py | 123 | 123 | 0 | 0%
src/scicom/historicalletters/model.py | 102 | 102 | 0 | 0%
src/scicom/historicalletters/server.py | 26 | 26 | 0 | 0%
src/scicom/historicalletters/space.py | 33 | 33 | 0 | 0%
src/scicom/historicalletters/utils.py | 35 | 35 | 0 | 0%
src/scicom/knowledgespread/SimpleContinuousModule.py | 23 | 23 | 0 | 0%
src/scicom/knowledgespread/__init__.py | 0 | 0 | 0 | 100%
src/scicom/knowledgespread/agents.py | 73 | 73 | 0 | 0%
src/scicom/knowledgespread/app.py | 9 | 9 | 0 | 0%
src/scicom/knowledgespread/model.py | 71 | 71 | 0 | 0%
src/scicom/knowledgespread/server.py | 70 | 70 | 0 | 0%
src/scicom/knowledgespread/utils.py | 128 | 128 | 0 | 0%
src/scicom/randomletters/SimpleContinuousModule.py | 24 | 24 | 0 | 0%
src/scicom/randomletters/__init__.py | 0 | 0 | 0 | 100%
src/scicom/randomletters/agents.py | 74 | 74 | 0 | 0%
src/scicom/randomletters/model.py | 34 | 34 | 0 | 0%
src/scicom/randomletters/server.py | 32 | 32 | 0 | 0%
src/scicom/run.py | 13 | 13 | 0 | 0%
src/scicom/utilities/__init__.py | 0 | 0 | 0 | 100%
src/scicom/utilities/statistics.py | 10 | 10 | 0 | 0%
Total | 880 | 880 | 0 | 0%

No items found using the specified filter.